Class: Google::Apis::DeveloperknowledgeV1alpha::Document
- Inherits:
-
Object
- Object
- Google::Apis::DeveloperknowledgeV1alpha::Document
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/developerknowledge_v1alpha/classes.rb,
lib/google/apis/developerknowledge_v1alpha/representations.rb,
lib/google/apis/developerknowledge_v1alpha/representations.rb
Overview
A Document represents a page of documentation in the Developer Knowledge corpus, like the page at https://docs.cloud.google.com/storage/docs/creating- buckets.
Instance Attribute Summary collapse
-
#content ⇒ String
Output only.
-
#content_length_bytes ⇒ Fixnum
Output only.
-
#data_source ⇒ String
Output only.
-
#description ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#title ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#uri ⇒ String
Output only.
-
#view ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Document
constructor
A new instance of Document.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Document
Returns a new instance of Document.
273 274 275 |
# File 'lib/google/apis/developerknowledge_v1alpha/classes.rb', line 273 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content ⇒ String
Output only. Contains the full content of the document in Markdown format.
Corresponds to the JSON property content
226 227 228 |
# File 'lib/google/apis/developerknowledge_v1alpha/classes.rb', line 226 def content @content end |
#content_length_bytes ⇒ Fixnum
Output only. The length of the content field in bytes.
Corresponds to the JSON property contentLengthBytes
231 232 233 |
# File 'lib/google/apis/developerknowledge_v1alpha/classes.rb', line 231 def content_length_bytes @content_length_bytes end |
#data_source ⇒ String
Output only. Specifies the data source of the document. Example data source:
firebase.google.com
Corresponds to the JSON property dataSource
237 238 239 |
# File 'lib/google/apis/developerknowledge_v1alpha/classes.rb', line 237 def data_source @data_source end |
#description ⇒ String
Output only. Provides a description of the document.
Corresponds to the JSON property description
242 243 244 |
# File 'lib/google/apis/developerknowledge_v1alpha/classes.rb', line 242 def description @description end |
#name ⇒ String
Identifier. Contains the resource name of the document. Format: documents/
uri_without_scheme`Example:documents/docs.cloud.google.com/storage/docs/
creating-buckets
Corresponds to the JSON propertyname`
249 250 251 |
# File 'lib/google/apis/developerknowledge_v1alpha/classes.rb', line 249 def name @name end |
#title ⇒ String
Output only. Provides the title of the document.
Corresponds to the JSON property title
254 255 256 |
# File 'lib/google/apis/developerknowledge_v1alpha/classes.rb', line 254 def title @title end |
#update_time ⇒ String
Output only. Represents the timestamp when the content or metadata of the
document was last updated.
Corresponds to the JSON property updateTime
260 261 262 |
# File 'lib/google/apis/developerknowledge_v1alpha/classes.rb', line 260 def update_time @update_time end |
#uri ⇒ String
Output only. Provides the URI of the content, such as docs.cloud.google.com/
storage/docs/creating-buckets.
Corresponds to the JSON property uri
266 267 268 |
# File 'lib/google/apis/developerknowledge_v1alpha/classes.rb', line 266 def uri @uri end |
#view ⇒ String
Output only. Specifies the DocumentView of the document.
Corresponds to the JSON property view
271 272 273 |
# File 'lib/google/apis/developerknowledge_v1alpha/classes.rb', line 271 def view @view end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/google/apis/developerknowledge_v1alpha/classes.rb', line 278 def update!(**args) @content = args[:content] if args.key?(:content) @content_length_bytes = args[:content_length_bytes] if args.key?(:content_length_bytes) @data_source = args[:data_source] if args.key?(:data_source) @description = args[:description] if args.key?(:description) @name = args[:name] if args.key?(:name) @title = args[:title] if args.key?(:title) @update_time = args[:update_time] if args.key?(:update_time) @uri = args[:uri] if args.key?(:uri) @view = args[:view] if args.key?(:view) end |