Class: Google::Apis::DeveloperknowledgeV1alpha::DocumentReference

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/developerknowledge_v1alpha/classes.rb,
lib/google/apis/developerknowledge_v1alpha/representations.rb,
lib/google/apis/developerknowledge_v1alpha/representations.rb

Overview

Represents a reference to a document.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DocumentReference

Returns a new instance of DocumentReference.



357
358
359
# File 'lib/google/apis/developerknowledge_v1alpha/classes.rb', line 357

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#document_chunkGoogle::Apis::DeveloperknowledgeV1alpha::DocumentChunk

A DocumentChunk represents a piece of content from a Document in the DeveloperKnowledge corpus. To fetch the entire document content, pass the parent to DeveloperKnowledge.GetDocument or DeveloperKnowledge. BatchGetDocuments. Corresponds to the JSON property documentChunk



355
356
357
# File 'lib/google/apis/developerknowledge_v1alpha/classes.rb', line 355

def document_chunk
  @document_chunk
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



362
363
364
# File 'lib/google/apis/developerknowledge_v1alpha/classes.rb', line 362

def update!(**args)
  @document_chunk = args[:document_chunk] if args.key?(:document_chunk)
end