Class: Google::Apis::DeveloperknowledgeV1alpha::SearchDocumentChunksResponse
- Inherits:
-
Object
- Object
- Google::Apis::DeveloperknowledgeV1alpha::SearchDocumentChunksResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/developerknowledge_v1alpha/classes.rb,
lib/google/apis/developerknowledge_v1alpha/representations.rb,
lib/google/apis/developerknowledge_v1alpha/representations.rb
Overview
Response message for DeveloperKnowledge.SearchDocumentChunks.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Provides a token that can be sent as
page_tokento retrieve the next page. -
#results ⇒ Array<Google::Apis::DeveloperknowledgeV1alpha::DocumentChunk>
Contains the search results for the given query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SearchDocumentChunksResponse
constructor
A new instance of SearchDocumentChunksResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SearchDocumentChunksResponse
Returns a new instance of SearchDocumentChunksResponse.
385 386 387 |
# File 'lib/google/apis/developerknowledge_v1alpha/classes.rb', line 385 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Provides a token that can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
Corresponds to the JSON property nextPageToken
375 376 377 |
# File 'lib/google/apis/developerknowledge_v1alpha/classes.rb', line 375 def next_page_token @next_page_token end |
#results ⇒ Array<Google::Apis::DeveloperknowledgeV1alpha::DocumentChunk>
Contains the search results for the given query. Each DocumentChunk in this
list contains a snippet of content relevant to the search query. Use the
DocumentChunk.parent field of each result with DeveloperKnowledge.GetDocument
or DeveloperKnowledge.BatchGetDocuments to retrieve the full document content.
Corresponds to the JSON property results
383 384 385 |
# File 'lib/google/apis/developerknowledge_v1alpha/classes.rb', line 383 def results @results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
390 391 392 393 |
# File 'lib/google/apis/developerknowledge_v1alpha/classes.rb', line 390 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @results = args[:results] if args.key?(:results) end |