Class: Google::Apis::DeveloperknowledgeV1alpha::AnswerQueryRequest
- Inherits:
-
Object
- Object
- Google::Apis::DeveloperknowledgeV1alpha::AnswerQueryRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/developerknowledge_v1alpha/classes.rb,
lib/google/apis/developerknowledge_v1alpha/representations.rb,
lib/google/apis/developerknowledge_v1alpha/representations.rb
Overview
Request message for DeveloperKnowledge.AnswerQuery.
Instance Attribute Summary collapse
-
#filter ⇒ String
Optional.
-
#query ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AnswerQueryRequest
constructor
A new instance of AnswerQueryRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AnswerQueryRequest
Returns a new instance of AnswerQueryRequest.
129 130 131 |
# File 'lib/google/apis/developerknowledge_v1alpha/classes.rb', line 129 def initialize(**args) update!(**args) end |
Instance Attribute Details
#filter ⇒ String
Optional. Applies a strict filter to the search results used to ground the
answer. The expression supports a subset of the syntax described at https://
google.aip.dev/160. Supported fields for filtering: * content_length_bytes (
INTEGER): The length of the Document.content field in bytes. * data_source
(STRING): The source of the document, e.g. docs.cloud.google.com. See https:/
/developers.google.com/knowledge/reference/corpus-reference for the complete
list of data sources in the corpus. * update_time (TIMESTAMP): The timestamp
of when the document was last meaningfully updated. A meaningful update is one
that changes document's markdown content or metadata. * uri (STRING): The
document URI, e.g. https://docs.cloud.google.com/bigquery/docs/tables.
INTEGER fields support =, <, <=, >, and >= operators. STRING fields
support = (equals) and != (not equals) operators for exact match on
the whole string. Partial match, prefix match, and regexp match are not
supported. TIMESTAMP fields support =, <, <=, >, and >= operators.
Timestamps must be in RFC-3339 format, e.g., "2025-01-01T00:00:00Z". You can
combine expressions using AND, OR, and NOT (or -) logical operators.
OR has higher precedence than AND. Use parentheses for explicit precedence
grouping. Examples: * Filter by Document.content_length_bytes:
content_length_bytes < 50000 * data_source = "docs.cloud.google.com" OR
data_source = "firebase.google.com" * data_source != "firebase.google.com" *
update_time < "2024-01-01T00:00:00Z" * update_time >= "2025-01-22T00:00:
00Z" AND (data_source = "developer.chrome.com" OR data_source = "web.dev") *
uri = "https://docs.cloud.google.com/release-notes" The filter string must
not exceed 500 characters; values longer than 500 characters will result in an
INVALID_ARGUMENT error.
Corresponds to the JSON property filter
122 123 124 |
# File 'lib/google/apis/developerknowledge_v1alpha/classes.rb', line 122 def filter @filter end |
#query ⇒ String
Required. The query to answer.
Corresponds to the JSON property query
127 128 129 |
# File 'lib/google/apis/developerknowledge_v1alpha/classes.rb', line 127 def query @query end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
134 135 136 137 |
# File 'lib/google/apis/developerknowledge_v1alpha/classes.rb', line 134 def update!(**args) @filter = args[:filter] if args.key?(:filter) @query = args[:query] if args.key?(:query) end |