Class: Google::Apis::DeveloperknowledgeV1alpha::Document
- Inherits:
-
Object
- Object
- Google::Apis::DeveloperknowledgeV1alpha::Document
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/developerknowledge_v1alpha/classes.rb,
lib/google/apis/developerknowledge_v1alpha/representations.rb,
lib/google/apis/developerknowledge_v1alpha/representations.rb
Overview
A Document represents a piece of content from the Developer Knowledge corpus.
Instance Attribute Summary collapse
-
#content ⇒ String
Output only.
-
#data_source ⇒ String
Output only.
-
#description ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#title ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#uri ⇒ String
Output only.
-
#view ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Document
constructor
A new instance of Document.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Document
Returns a new instance of Document.
150 151 152 |
# File 'lib/google/apis/developerknowledge_v1alpha/classes.rb', line 150 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content ⇒ String
Output only. Contains the full content of the document in Markdown format.
Corresponds to the JSON property content
108 109 110 |
# File 'lib/google/apis/developerknowledge_v1alpha/classes.rb', line 108 def content @content end |
#data_source ⇒ String
Output only. Specifies the data source of the document. Example data source:
firebase.google.com
Corresponds to the JSON property dataSource
114 115 116 |
# File 'lib/google/apis/developerknowledge_v1alpha/classes.rb', line 114 def data_source @data_source end |
#description ⇒ String
Output only. Provides a description of the document.
Corresponds to the JSON property description
119 120 121 |
# File 'lib/google/apis/developerknowledge_v1alpha/classes.rb', line 119 def description @description end |
#name ⇒ String
Identifier. Contains the resource name of the document. Format: documents/
uri_without_scheme`Example:documents/docs.cloud.google.com/storage/docs/
creating-buckets
Corresponds to the JSON propertyname`
126 127 128 |
# File 'lib/google/apis/developerknowledge_v1alpha/classes.rb', line 126 def name @name end |
#title ⇒ String
Output only. Provides the title of the document.
Corresponds to the JSON property title
131 132 133 |
# File 'lib/google/apis/developerknowledge_v1alpha/classes.rb', line 131 def title @title end |
#update_time ⇒ String
Output only. Represents the timestamp when the content or metadata of the
document was last updated.
Corresponds to the JSON property updateTime
137 138 139 |
# File 'lib/google/apis/developerknowledge_v1alpha/classes.rb', line 137 def update_time @update_time end |
#uri ⇒ String
Output only. Provides the URI of the content, such as docs.cloud.google.com/
storage/docs/creating-buckets.
Corresponds to the JSON property uri
143 144 145 |
# File 'lib/google/apis/developerknowledge_v1alpha/classes.rb', line 143 def uri @uri end |
#view ⇒ String
Output only. Specifies the DocumentView of the document.
Corresponds to the JSON property view
148 149 150 |
# File 'lib/google/apis/developerknowledge_v1alpha/classes.rb', line 148 def view @view end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
155 156 157 158 159 160 161 162 163 164 |
# File 'lib/google/apis/developerknowledge_v1alpha/classes.rb', line 155 def update!(**args) @content = args[:content] if args.key?(:content) @data_source = args[:data_source] if args.key?(:data_source) @description = args[:description] if args.key?(:description) @name = args[:name] if args.key?(:name) @title = args[:title] if args.key?(:title) @update_time = args[:update_time] if args.key?(:update_time) @uri = args[:uri] if args.key?(:uri) @view = args[:view] if args.key?(:view) end |