Class: Google::Apis::DeveloperknowledgeV1alpha::DocumentReference
- Inherits:
-
Object
- Object
- Google::Apis::DeveloperknowledgeV1alpha::DocumentReference
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/developerknowledge_v1alpha/classes.rb,
lib/google/apis/developerknowledge_v1alpha/representations.rb,
lib/google/apis/developerknowledge_v1alpha/representations.rb
Overview
Represents a reference to a document.
Instance Attribute Summary collapse
-
#document_chunk ⇒ Google::Apis::DeveloperknowledgeV1alpha::DocumentChunk
A DocumentChunk represents a piece of content from a Document in the DeveloperKnowledge corpus.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DocumentReference
constructor
A new instance of DocumentReference.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DocumentReference
Returns a new instance of DocumentReference.
309 310 311 |
# File 'lib/google/apis/developerknowledge_v1alpha/classes.rb', line 309 def initialize(**args) update!(**args) end |
Instance Attribute Details
#document_chunk ⇒ Google::Apis::DeveloperknowledgeV1alpha::DocumentChunk
A DocumentChunk represents a piece of content from a Document in the
DeveloperKnowledge corpus. To fetch the entire document content, pass the
parent to DeveloperKnowledge.GetDocument or DeveloperKnowledge.
BatchGetDocuments.
Corresponds to the JSON property documentChunk
307 308 309 |
# File 'lib/google/apis/developerknowledge_v1alpha/classes.rb', line 307 def document_chunk @document_chunk end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
314 315 316 |
# File 'lib/google/apis/developerknowledge_v1alpha/classes.rb', line 314 def update!(**args) @document_chunk = args[:document_chunk] if args.key?(:document_chunk) end |