Class: Google::Apis::DeveloperknowledgeV1alpha::SearchDocumentChunksResponse
- Inherits:
-
Object
- Object
- Google::Apis::DeveloperknowledgeV1alpha::SearchDocumentChunksResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/developerknowledge_v1alpha/classes.rb,
lib/google/apis/developerknowledge_v1alpha/representations.rb,
lib/google/apis/developerknowledge_v1alpha/representations.rb
Overview
Response message for DeveloperKnowledge.SearchDocumentChunks.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Optional.
-
#results ⇒ Array<Google::Apis::DeveloperknowledgeV1alpha::DocumentChunk>
Contains the search results for the given query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SearchDocumentChunksResponse
constructor
A new instance of SearchDocumentChunksResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SearchDocumentChunksResponse
Returns a new instance of SearchDocumentChunksResponse.
337 338 339 |
# File 'lib/google/apis/developerknowledge_v1alpha/classes.rb', line 337 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Optional. Provides a token that can be sent as page_token to retrieve the
next page. If this field is omitted, there are no subsequent pages.
Corresponds to the JSON property nextPageToken
327 328 329 |
# File 'lib/google/apis/developerknowledge_v1alpha/classes.rb', line 327 def next_page_token @next_page_token end |
#results ⇒ Array<Google::Apis::DeveloperknowledgeV1alpha::DocumentChunk>
Contains the search results for the given query. Each DocumentChunk in this
list contains a snippet of content relevant to the search query. Use the
DocumentChunk.parent field of each result with DeveloperKnowledge.GetDocument
or DeveloperKnowledge.BatchGetDocuments to retrieve the full document content.
Corresponds to the JSON property results
335 336 337 |
# File 'lib/google/apis/developerknowledge_v1alpha/classes.rb', line 335 def results @results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
342 343 344 345 |
# File 'lib/google/apis/developerknowledge_v1alpha/classes.rb', line 342 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @results = args[:results] if args.key?(:results) end |